@@ -152,9 +152,10 @@ class TableEntry:
             return False
         elif self.properties[0] == 'Sk':
             if 'EMOJI MODIFIER' in self.comment:
-                # These codepoints are fullwidth when used without emoji, 0-width with.
-                # Generate code that expects the best case, that is always combined
-                return wide == 0
+                # Standalone Fitzpatrick modifiers display as wide (2 cells).
+                # Zero-width when following an emoji base is handled contextually
+                # in wcswidth() and width().
+                return wide == 2
             elif 'FULLWIDTH' in self.comment:
                 # Some codepoints in 'Sk' categories are fullwidth(!)
                 # at this time just 3, FULLWIDTH: CIRCUMFLEX ACCENT, GRAVE ACCENT, and MACRON
@@ -399,6 +400,13 @@ def fetch_table_wide_data() -> UnicodeTableRenderCtx:
     # finally, join with atypical 'wide' characters defined by category 'Sk',
     fname = UnicodeDataFile.DerivedGeneralCategory(version)
     table[version].values.update(parse_category(fname=fname, wide=2).values)
+
+    # Add Regional Indicator symbols (U+1F1E6..U+1F1FF). Though classified as
+    # Neutral in EastAsianWidth.txt, terminals universally render these as
+    # double-width. Pairing (flag emoji) is handled contextually in wcswidth()
+    # and width().
+    table[version].values.update(range(0x1F1E6, 0x1F1FF + 1))
+
     return UnicodeTableRenderCtx('WIDE_EASTASIAN', table)
 
 
@@ -463,6 +471,12 @@ def fetch_table_zero_data() -> UnicodeTableRenderCtx:
             fname=UnicodeDataFile.PropList(version),
             property_name='Prepended_Concatenation_Mark'))
 
+    # Remove Emoji Modifier Fitzpatrick types (U+1F3FB..U+1F3FF) from zero-width.
+    # Standalone they display as wide (2 cells); they are only zero-width when
+    # following an emoji base character in sequence, handled contextually in
+    # wcswidth() and width().
+    table[version].values -= set(range(0x1F3FB, 0x1F3FF + 1))
+
     return UnicodeTableRenderCtx('ZERO_WIDTH', table)
 
 
@@ -779,6 +793,47 @@ def parse_indic_conjunct_breaks(fname: str) -> dict[str, TableDef]:
     }
 
 
+ISC_VALUES = ('Consonant',)
+
+
+def parse_indic_syllabic_category(fname: str) -> dict[str, TableDef]:
+    """
+    Parse IndicSyllabicCategory.txt for Consonant property.
+
+    See https://www.unicode.org/reports/tr44/#Indic_Syllabic_Category
+    """
+    print(f'parsing {fname} for ISC: ', end='', flush=True)
+    values_by_isc: dict[str, set[int]] = {val: set() for val in ISC_VALUES}
+
+    with open(fname, encoding='utf-8') as f:
+        for line in f:
+            data, _, comment = line.partition('#')
+            data = data.strip()
+            if not data:
+                continue
+
+            parts = [p.strip() for p in data.split(';')]
+            if len(parts) < 2:
+                continue
+
+            code_points_str, prop_value = parts[0], parts[1]
+
+            if prop_value in values_by_isc:
+                if '..' in code_points_str:
+                    start, end = code_points_str.split('..')
+                    values_by_isc[prop_value].update(
+                        range(int(start, 16), int(end, 16) + 1)
+                    )
+                else:
+                    values_by_isc[prop_value].add(int(code_points_str, 16))
+
+    print('ok')
+    return {
+        f'ISC_{val.upper()}': TableDef('IndicSyllabicCategory', 'see file', values)
+        for val, values in values_by_isc.items()
+    }
+
+
 def parse_derived_core_property(fname: str, property_name: str) -> set[int]:
     """Parse DerivedCoreProperties.txt for a specific property."""
     print(f'parsing {fname} for {property_name}: ', end='', flush=True)
@@ -822,6 +877,9 @@ def fetch_table_grapheme_data() -> GraphemeTableRenderCtx:
     tables.update(parse_indic_conjunct_breaks(
         UnicodeDataFile.DerivedCoreProperties(latest_version)
     ))
+    tables.update(parse_indic_syllabic_category(
+        UnicodeDataFile.IndicSyllabicCategory(latest_version)
+    ))
 
     return GraphemeTableRenderCtx(str(latest_version), tables)
 
@@ -848,6 +906,7 @@ class UnicodeDataFile:
     URL_DERIVED_CORE_PROPS = 'https://www.unicode.org/Public/{version}/ucd/DerivedCoreProperties.txt'
     URL_PROP_LIST = 'https://www.unicode.org/Public/{version}/ucd/PropList.txt'
     URL_GRAPHEME_BREAK_TEST = 'https://www.unicode.org/Public/{version}/ucd/auxiliary/GraphemeBreakTest.txt'
+    URL_INDIC_SYLLABIC_CATEGORY = 'https://www.unicode.org/Public/{version}/ucd/IndicSyllabicCategory.txt'
     URL_UDHR_ZIP = 'http://efele.net/udhr/assemblies/udhr_txt.zip'
 
     @classmethod
@@ -920,6 +979,12 @@ class UnicodeDataFile:
         cls.do_retrieve(url=cls.URL_PROP_LIST.format(version=version), fname=fname)
         return fname
 
+    @classmethod
+    def IndicSyllabicCategory(cls, version: str) -> str:
+        fname = os.path.join(PATH_DATA, f'IndicSyllabicCategory-{version}.txt')
+        cls.do_retrieve(url=cls.URL_INDIC_SYLLABIC_CATEGORY.format(version=version), fname=fname)
+        return fname
+
     @classmethod
     def TestGraphemeBreakTest(cls) -> str:
         version = fetch_unicode_versions()[-1]
@@ -1164,6 +1229,7 @@ def fetch_all_data_files(fetch_all_versions: bool = False) -> None:
     UnicodeDataFile.EmojiData(version)
     UnicodeDataFile.DerivedCoreProperties(version)
     UnicodeDataFile.PropList(version)
+    UnicodeDataFile.IndicSyllabicCategory(version)
 
     # Fetch test data files
     UnicodeDataFile.TestEmojiVariationSequences()
